@@ -74,7 +74,7 @@ Equipment Corporation.
 ******************************************************************/
 
 /* $Xorg: resource.c,v 1.5 2001/02/09 02:04:40 xorgcvs Exp $ */
-/* $XdotOrg: xc/programs/Xserver/dix/resource.c,v 1.1.4.2.2.1 2004/03/17 20:30:12 ago Exp $ */
+/* $XdotOrg: xc/programs/Xserver/dix/resource.c,v 1.1.4.2.2.2 2004/09/15 16:33:37 ago Exp $ */
 /* $TOG: resource.c /main/41 1998/02/09 14:20:31 kaleb $ */
 
 /*	Routines to manage various kinds of resources:
@@ -559,7 +559,7 @@ FreeResource(id, skipDeleteFuncType)
 	}
     }
     if (!gotOne)
-	FatalError("Freeing resource id=%lX which isn't there",
+	ErrorF("Freeing resource id=%lX which isn't there.\n",
 		   (unsigned long)id);
 }
 
