@@ -30,9 +30,7 @@ from The Open Group.
 
 #include "win.h"
 #include "winmsg.h"
-#ifdef XWIN_XF86CONFIG
 #include "winconfig.h"
-#endif
 #include "winprefs.h"
 #include "X11/Xlocale.h"
 #include <mntent.h>
@@ -375,7 +373,7 @@ OsVendorInit (void)
   }  
   LogSetParameter (XLOG_FLUSH, 1);
   LogSetParameter (XLOG_VERBOSITY, g_iLogVerbose);
-  LogSetParameter (XLOG_FILE_VERBOSITY, g_iLogVerbose);
+  LogSetParameter (XLOG_FILE_VERBOSITY, 1);
 
   /* Log the version information */
   if (serverGeneration == 1)
@@ -578,6 +576,10 @@ ddxUseMsg(void)
 		  MB_ICONINFORMATION);
 }
 
+/* ddxInitGlobals - called by |InitGlobals| from os/util.c */
+void ddxInitGlobals(void)
+{
+}
 
 #ifdef DDXTIME /* from ServerOSDefines */
 CARD32
@@ -631,6 +633,7 @@ InitOutput (ScreenInfo *screenInfo, int argc, char *argv[])
   winMsg(X_INFO, "XF86Config is not supported\n");
   winMsg(X_INFO, "See http://x.cygwin.com/docs/faq/cygwin-x-faq.html "
          "for more information\n");
+  winConfigFiles ();
 #endif
 
   /* Load preferences from XWinrc file */
