@@ -48,6 +48,17 @@
 #define CYGDEBUG				NO
 #endif
 
+/* WM_XBUTTON Messages. They should go into w32api. */
+#ifndef WM_XBUTTONDOWN
+# define WM_XBUTTONDOWN 523
+#endif
+#ifndef WM_XBUTTONUP
+# define WM_XBUTTONUP 524
+#endif
+#ifndef WM_XBUTTONDBLCLK
+# define WM_XBUTTONDBLCLK 525
+#endif
+
 #define NEED_EVENTS
 
 #define WIN_DEFAULT_BPP				0
@@ -413,6 +424,9 @@ typedef struct
   Bool			fRootless;
 #ifdef XWIN_MULTIWINDOW
   Bool			fMultiWindow;
+#endif
+#if defined(XWIN_MULTIWINDOW) || defined(XWIN_MULTIWINDOWEXTWM)
+  Bool			fMultiMonitorOverride;
 #endif
   Bool                  fMultipleMonitors;
   Bool			fLessPointer;
@@ -497,6 +511,7 @@ typedef struct _winPrivScreenRec
   LPDIRECTDRAW4		pdd4;
   LPDIRECTDRAWSURFACE4	pddsShadow4;
   LPDIRECTDRAWSURFACE4	pddsPrimary4;
+  BOOL			fRetryCreateSurface;
 
   /* Privates used by both shadow fb DirectDraw servers */
   LPDIRECTDRAWCLIPPER	pddcPrimary;
@@ -719,7 +734,7 @@ Bool
 winAllocatePrivates (ScreenPtr pScreen);
 
 Bool
-winInitCmapPrivates (ColormapPtr pCmap);
+winInitCmapPrivates (ColormapPtr pCmap, int index);
 
 Bool
 winAllocateCmapPrivates (ColormapPtr pCmap);
